vpnengine/ikepolparser/inc/ikepolparser.h
branchRCL_3
changeset 46 29c8f9bc68e1
parent 44 735de8341ce4
child 49 5960d2d03390
--- a/vpnengine/ikepolparser/inc/ikepolparser.h	Tue Sep 14 23:16:15 2010 +0300
+++ b/vpnengine/ikepolparser/inc/ikepolparser.h	Wed Sep 15 13:20:54 2010 +0300
@@ -291,7 +291,8 @@
     TOwnCertInfo iOwnCert;
     TCertInfo iPrivKey;
     TCertInfo iPeerCert;
-    TBool     iUseCache;  // Use credential cache
+    TBool     iUseCache;   // Use credential cache
+    TBool     iSoftToken;  // Use soft token
 };